@@ -46,6 +46,10 @@ ENVIRONMENT::ENVIRONMENT (GLOBALDATA *global):_global(global),done(NULL),fp(NULL
   dFadingText		=	0.0;	// defaults to 0 for backwards compatibilities sake
   dShadowedText	=	0.0;	// defaults to 0 for backwards compatibilities sake
   current_wallType = 0;
+  custom_background = 0.0;
+  bitmap_filenames = NULL;
+  number_of_bitmaps = 0;
+  current_drawing_mode = DRAW_MODE_SOLID;
 
   done = new char[global->screenWidth];
   fp = new int[global->screenWidth];
@@ -65,7 +69,8 @@ ENVIRONMENT::ENVIRONMENT (GLOBALDATA *global):_global(global),done(NULL),fp(NULL
   sky = create_bitmap (global->screenWidth, global->screenHeight - MENUHEIGHT);
   if (!sky)
     cout << "Failed to create sky bitmap: " << allegro_error;
-
+  waiting_sky = NULL;
+  waiting_terrain = NULL;
   _global = global;
 
   initialise ();
@@ -79,8 +84,11 @@ ENVIRONMENT::ENVIRONMENT (GLOBALDATA *global):_global(global),done(NULL),fp(NULL
  *    *       */
 ENVIRONMENT::~ENVIRONMENT()
 {
+  int count;
+
   if (db)      destroy_bitmap(db);      db      = NULL;
   if (sky)     destroy_bitmap(sky);     sky     = NULL;
+  if (waiting_sky) destroy_bitmap(sky); waiting_sky = NULL;
   if (terrain) destroy_bitmap(terrain); terrain = NULL;
 
   _global = NULL;
@@ -93,6 +101,15 @@ ENVIRONMENT::~ENVIRONMENT()
   if (velocity) delete [] (velocity); velocity = NULL;
   if (dropIncr) delete [] (dropIncr); dropIncr = NULL;
   if (height)   delete [] (height);   height = NULL;
+  if (bitmap_filenames)
+  {
+     for (count = 0; count < number_of_bitmaps; count++)
+     {
+        if (bitmap_filenames[count]) 
+           free(bitmap_filenames[count]);
+     }
+     free(bitmap_filenames);
+  }
 }
 
 
@@ -104,45 +121,7 @@ name=value\n
 
 The function returns TRUE on success and FALSE on failure.
 -- Jesse
-
-switched to binary mode. The original method can be found below
--- Sven
 */
-int ENVIRONMENT::saveToFile (ofstream &ofsFile, bool aIsGameSave)
-{
-  bool bResult = true;
-
-  // First: Write Global identifier:
-  bResult = pushData(FILEPART_ENVIRON, ofsFile);
-
-  // Now we can push everything into the file:
-  if (bResult) bResult = pushData("Wind Strength    ", windstrength,       ofsFile);
-  if (bResult) bResult = pushData("Wind Variation   ", windvariation,      ofsFile);
-  if (bResult) bResult = pushData("Viscosity        ", viscosity,          ofsFile);
-  if (bResult) bResult = pushData("Gravity          ",   gravity,            ofsFile);
-  if (bResult) bResult = pushData("Weapon Tech Level", weapontechLevel,    ofsFile);
-  if (bResult) bResult = pushData("Item Tech Level  ", itemtechLevel,      ofsFile);
-  if (!aIsGameSave)
-    {
-      // The following options are not usefull in save games:
-      if (bResult) bResult = pushData("Meteors          ", meteors,            ofsFile);
-      if (bResult) bResult = pushData("Lightning        ", lightning,          ofsFile);
-      if (bResult) bResult = pushData("Satellite        ", satellite,          ofsFile);
-      if (bResult) bResult = pushData("Fog              ", fog,                ofsFile);
-      if (bResult) bResult = pushData("Land Type        ", landType,           ofsFile);
-      if (bResult) bResult = pushData("Land Slide Type  ", landSlideType,      ofsFile);
-      if (bResult) bResult = pushData("Land Slide Delay ", landSlideDelay,     ofsFile);
-      if (bResult) bResult = pushData("Falling Dirt Ball", falling_dirt_balls, ofsFile);
-      if (bResult) bResult = pushData("Wall Type        ", wallType,           ofsFile);
-      if (bResult) bResult = pushData("Boxed Mode       ", dBoxedMode,         ofsFile);
-      if (bResult) bResult = pushData("Fading Text      ", dFadingText,        ofsFile);
-      if (bResult) bResult = pushData("Shadowed Text    ", dShadowedText,      ofsFile);
-    }
-  if (bResult) bResult = pushData(FILEPART_ENDSECT, ofsFile);
-
-  return(bResult);
-}
-
 int ENVIRONMENT::saveToFile_Text (FILE *file)
 {
   if (! file) return FALSE;
@@ -167,7 +146,7 @@ int ENVIRONMENT::saveToFile_Text (FILE *file)
   fprintf (file, "TEXTSHADOW=%f\n", dShadowedText);
   fprintf (file, "LANDSLIDEDELAY=%f\n", landSlideDelay);
   fprintf (file, "FALLINGDIRTBALLS=%f\n", falling_dirt_balls);
-
+  fprintf (file, "CUSTOMBACKGROUND=%f\n", custom_background);
   fprintf (file, "***\n");
   return TRUE;
 }
@@ -211,6 +190,7 @@ int ENVIRONMENT::loadFromFile(ifstream &ifsFile)
       else if (!strcmp(chArea, "Boxed Mode       ")) bResult = popData(dBoxedMode,         ifsFile);
       else if (!strcmp(chArea, "Fading Text      ")) bResult = popData(dFadingText,        ifsFile);
       else if (!strcmp(chArea, "Shadowed Text    ")) bResult = popData(dShadowedText,      ifsFile);
+      else if (!strcmp(chArea, "Custom Background")) bResult = popData(custom_background,  ifsFile);
       else if (!bIsFinished && bIsData)
         bResult = popData(dData, ifsFile); // Something we do not know (any more/yet), so dump it!
     }
@@ -308,6 +288,8 @@ int ENVIRONMENT::loadFromFile_Text (FILE *file)
                 sscanf(value, "%lf", &landSlideDelay);
               else if (! strcasecmp(field, (char *)"fallingdirtballs") )
                 sscanf(value, "%lf", &falling_dirt_balls);
+              else if (! strcasecmp(field, (char *)"custombackground") )
+                sscanf(value, "%lf", &custom_background);
 
             }    // end of found field=value line
 
@@ -338,8 +320,8 @@ void ENVIRONMENT::initialise ()
   clear_to_color (db, WHITE);
   clear_to_color (terrain, PINK);
 
-  oldFogX = 0;
-  oldFogY = 0;
+  // oldFogX = 0;
+  // oldFogY = 0;
 
   combineUpdates = TRUE;
 }
@@ -453,17 +435,44 @@ void ENVIRONMENT::newRound ()
 
 int ENVIRONMENT::ingamemenu ()
 {
-  int button[INGAMEBUTTONS] = { -35, -10, 15 }, pressed, updatew[INGAMEBUTTONS];
-  char buttext[INGAMEBUTTONS][10] = { "Return", "Main Menu", "Quit" };
+  int button[INGAMEBUTTONS];
+  int pressed = -1;
+  int updatew[INGAMEBUTTONS];
+  char *buttext[INGAMEBUTTONS];
+  buttext[0] = _global->ingame->complete_text[69];
+  buttext[1] =  _global->ingame->complete_text[70];
+  buttext[2] = _global->ingame->complete_text[71];
+  buttext[3] =  _global->ingame->complete_text[72];
+  // char buttext_de[INGAMEBUTTONS][32] = { "Zuruck", "Hauptmenu", "Verlassen", "Skip AI" };
   int z, zz;
 
-  pressed = -1;
+  // Set/calcualte button size and positions
+  int button_width = 150;
+  int button_height = 20;
+  int button_space = 5;
+  int button_halfwidth = button_width / 2;
+  // int button_halfheight = button_height / 2;
+  int dialog_width = 200;
+  int dialog_height = ((INGAMEBUTTONS + 2) * button_height) + ((INGAMEBUTTONS + 1) * button_space);
+  int dialog_halfwidth = dialog_width / 2;
+  int dialog_halfheight = dialog_height / 2;
+
+  // Calculate button y values and set all button status to 0
+  int y = -dialog_halfheight + button_height + button_space;
+
   for (z = 0; z < INGAMEBUTTONS; z++)
+  {
     updatew[z] = 0;
+    button[z] = y;
+    y += button_height + button_space;
+  }
+
   if (! _global->os_mouse) show_mouse (NULL);
-  make_update (_global->halfWidth - 100, _global->halfHeight - 50, 200, 100);
-  rectfill (db, _global->halfWidth - 100, _global->halfHeight - 50, _global->halfWidth + 99, _global->halfHeight + 49, makecol (128, 128, 128));
-  rect (db, _global->halfWidth - 100, _global->halfHeight - 50, _global->halfWidth + 99, _global->halfHeight + 49, BLACK);
+   make_update (_global->halfWidth - dialog_halfwidth, _global->halfHeight - dialog_halfheight, dialog_width, dialog_height);
+   rectfill (db, _global->halfWidth - dialog_halfwidth, _global->halfHeight - dialog_halfheight, _global->halfWidth + dialog_halfwidth - 1, _global->halfHeight + dialog_halfheight - 1, makecol (128, 128, 128));
+   rect (db, _global->halfWidth - dialog_halfwidth, _global->halfHeight - dialog_halfheight, _global->halfWidth + dialog_halfwidth - 1, _global->halfHeight + dialog_halfheight - 1, BLACK);
+
+
   while (1)
     {
       LINUX_SLEEP;
@@ -479,8 +488,8 @@ int ENVIRONMENT::ingamemenu ()
           zz = 0;
           for (z = 0; z < INGAMEBUTTONS; z++)
             {
-              if (mouse_x >= _global->halfWidth - 75 && mouse_x < _global->halfWidth + 75 && mouse_y >= button[z] + _global->halfHeight
-                  && mouse_y < button[z] + 20 + _global->halfHeight)
+                if (mouse_x >= _global->halfWidth - button_halfwidth && mouse_x < _global->halfWidth + button_halfwidth && mouse_y >= button[z] + _global->halfHeight
+                   && mouse_y < button[z] + button_height + _global->halfHeight)
                 {
                   zz = 1;
                   if (pressed > -1)
@@ -503,17 +512,17 @@ int ENVIRONMENT::ingamemenu ()
           if (updatew[z])
             {
               updatew[z] = 0;
-              make_update (_global->halfWidth - 75, _global->halfHeight + button[z], 150, 20);
+              make_update (_global->halfWidth - button_halfwidth, _global->halfHeight + button[z], button_width, button_height);
             }
         }
-      make_update (mouse_x, mouse_y, ((BITMAP *) (_global->gfxData.M[0].dat))->w, ((BITMAP *) (_global->gfxData.M[0].dat))->h);
-      make_update (lx, ly, ((BITMAP *) (_global->gfxData.M[0].dat))->w, ((BITMAP *) (_global->gfxData.M[0].dat))->h);
+      make_update (mouse_x, mouse_y, ((BITMAP *) (_global->misc[0]))->w, ((BITMAP *) (_global->misc[0]))->h);
+      make_update (lx, ly, ((BITMAP *) (_global->misc[0]))->w, ((BITMAP *) (_global->misc[0]))->h);
       lx = mouse_x;
       ly = mouse_y;
       if (! _global->os_mouse)  show_mouse (NULL);
       for (z = 0; z < INGAMEBUTTONS; z++)
         {
-          draw_sprite (db, (BITMAP *) _global->gfxData.M[(pressed == z) ? 8 : 7].dat, _global->halfWidth - 75, _global->halfHeight + button[z]);
+          draw_sprite (db, (BITMAP *) _global->misc[(pressed == z) ? 8 : 7], _global->halfWidth - button_halfwidth, _global->halfHeight + button[z]);
           textout_centre_ex (db, font, buttext[z], _global->halfWidth, _global->halfHeight + button[z] + 6, WHITE, -1);
         }
       if (! _global->os_mouse) show_mouse (db);
@@ -525,19 +534,6 @@ void ENVIRONMENT::do_updates ()
 {
   int count;
 
-  /*
-  if (fog && _global->currTank) {
-  int x, y;
-  x = (int)_global->currTank->x;
-  y = (int)_global->currTank->y;
-  if (oldFogX != x || oldFogY != y) {
-  rectfill (screen, oldFogX - 100, oldFogY - 100, oldFogX + 100, oldFogY + 100, makecol (128, 128, 128));
-  oldFogX = x;
-  oldFogY = y;
-  }
-  blit (db, screen, x - 100, y - 100, x - 100, y - 100, 200, 200);
-  blit (db, screen, 0, 0, 0, 0, _global->screenWidth, MENUHEIGHT);
-  } else { */
   bool bIsBgUpdNeeded = false;
   if (_global->lastUpdatesCount)
     bIsBgUpdNeeded = true;
@@ -955,3 +951,36 @@ int ENVIRONMENT::getAvgBgColor(int aTopLeftX, int aTopLeftY, int aBotRightX, int
 
       return(makecol(iRed, iGreen, iBlue));
     }
+
+
+
+
+/*
+ * This function puts all the of the environment settings back
+ * to their default values. These are settings which get written
+ * to the config file.
+ * -- Jesse
+ *  */ 
+void ENVIRONMENT::Reset_Options()
+{
+  windstrength = 8;
+  windvariation = 1;
+  viscosity = 0.5;
+  gravity = 0.150;
+  weapontechLevel = 5;
+  itemtechLevel = 5;
+  meteors = 0;
+  lightning = 0;
+  satellite = 0.0;
+  fog = 0;
+  landType = LANDTYPE_RANDOM;
+  landSlideType = LANDSLIDE_GRAVITY;
+  landSlideDelay = MAX_GRAVITY_DELAY;
+  falling_dirt_balls = 0.0;
+  wallType = 0.0;
+  dBoxedMode = 0.0;
+  dFadingText = 0.0;
+  dShadowedText = 0.0;
+  custom_background = 0.0;
+}
+
