@@ -21,22 +21,25 @@
 #include "player.h"
 #include "globaldata.h"
 #include "files.h"
+#include "network.h"
+
 
 GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdates(NULL),allPlayers(NULL),
-    players(NULL),currTank(NULL),SOUND(NULL),saved_game_list(NULL)
+    players(NULL),currTank(NULL),saved_game_list(NULL)
 {
   tank_status = (char *)calloc(128, sizeof(char));
   if (!tank_status)
     {
-      perror ( (char *)"globaldata.cpp: Failed allocating memory for tank_status in GLOBALDATA::GLOBALDATA");
-      exit (1);
+      perror ( "globaldata.cpp: Failed allocating memory for tank_status in GLOBALDATA::GLOBALDATA");
+      // exit (1);
     }
 
   initialise ();
   language = LANGUAGE_ENGLISH;
   sound = 1.0;
   name_above_tank = TRUE;
-  colourDepth = 16;
+  colourDepth = 0;
+  client_player = NULL;
   screenWidth = DEFAULT_SCREEN_WIDTH;
   screenHeight = DEFAULT_SCREEN_HEIGHT;
   width_override = height_override = 0;
@@ -56,13 +59,13 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   ditherGradients = 1;
   detailedLandscape = 0;
   detailedSky = 0;
-  colour_theme = 0.0;
+  colour_theme = COLOUR_THEME_CRISPY;
   startmoney = 15000;
   turntype = TURN_RANDOM;
   skipComputerPlay = SKIP_HUMANS_DEAD;
-  dataDir = (char *)DATA_DIR;
+  dataDir = DATA_DIR;
   os_mouse = 1.0;
-  full_screen = false;
+  full_screen = FULL_SCREEN_FALSE;
   interest = 1.25;
   scoreHitUnit = 75;
   scoreSelfHit = 0;
@@ -77,36 +80,45 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   saved_game_list = NULL;
   max_fire_time = 0.0;
   close_button_pressed = false;
+  divide_money = 0.0;
+  sound_driver = SOUND_AUTODETECT;
+  update_string = NULL;
+  check_for_updates = 1.0;
+  demo_mode = false;
+  env = NULL;
+  war_quotes = instructions = ingame = NULL;
+  gloat = revenge = retaliation = kamikaze = suicide = NULL;
 
   updates = new BOX[MAXUPDATES];
   if (!updates)
     {
-      perror ( (char *)"globaldata.cc: Failed allocating memory for updates in GLOBALDATA::GLOBALDATA");
-      exit (1);
+      perror ( "globaldata.cc: Failed allocating memory for updates in GLOBALDATA::GLOBALDATA");
+      // exit (1);
     }
   lastUpdates = new BOX[MAXUPDATES];
   if (!lastUpdates)
     {
-      perror ( (char *)"globaldata.cc: Failed allocating memory for lastUpdates in GLOBALDATA::GLOBALDATA");
-      exit (1);
+      perror ( "globaldata.cc: Failed allocating memory for lastUpdates in GLOBALDATA::GLOBALDATA");
+      // exit (1);
     }
   updateCount = 0;
   lastUpdatesCount = 0;
 
-  players = new PLAYER*[MAXPLAYERS];
+  // players = new PLAYER*[MAXPLAYERS];
+  players = (PLAYER **) calloc( MAXPLAYERS, sizeof(PLAYER *) );
   if (!players)
     {
-      perror ( (char *)"globaldata.cc: Failed allocating memory for players in GLOBALDATA::GLOBALDATA");
-      exit (1);
+      perror ( "globaldata.cc: Failed allocating memory for players in GLOBALDATA::GLOBALDATA");
+      // exit (1);
     }
   numPlayers = 0;
   rounds = 5;
 
-  allPlayers = (PLAYER**)malloc (sizeof (PLAYER*));
+  allPlayers = (PLAYER**) calloc (1, sizeof (PLAYER*));
   if (!allPlayers)
     {
       fprintf (stderr, "Failed allocating memory for players in globaldata.cc\n");
-      exit (1);
+      // exit (1);
     }
 
   for (int count = 0; count < 360; count++)
@@ -123,62 +135,62 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
 #ifdef DEBUG_AIM_SHOW
   bASD = false; // will be set to true after the first drawing of the map
 #endif
+  enable_network = 0.0;
+#ifdef NETWORK
+  listen_port = DEFAULT_LISTEN_PORT;
+#endif
+  strcpy(server_name, "127.0.0.1");
+  strcpy(server_port, "25645");
+  play_music = 1.0;
+  background_music = NULL;
+  music_dir = NULL;
+  unicode = NULL;
+  regular_font = font;
+  draw_background = TRUE;
 }
 
+
+
+GLOBALDATA::~GLOBALDATA()
+{
+  int index;
+
+  if (tank_status)
+  {
+      tank_status[0] = 0;
+      free(tank_status);
+  }
+
+  index = 0;
+  while (sounds[index])
+  {
+     destroy_sample(sounds[index]);
+  }
+  free(sounds);
+
+  if (music_dir)
+     closedir(music_dir);
+  if (unicode)
+     destroy_font(unicode);
+
+  if (war_quotes) delete war_quotes;
+  if (instructions) delete instructions;
+  if (ingame) delete ingame;
+  if (gloat) delete gloat;
+  if (revenge) delete revenge;
+  if (retaliation) delete retaliation;
+  if (kamikaze) delete kamikaze;
+  if (suicide) delete suicide;
+}
+
+
+
+
 /*
 This function saves the global data to a text file. If all goes
 well, TRUE is returned, on error, FALSE is returned.
 -- Jesse
-
-New method to save to binary file. The old one is below!
--- Sven
 */
-int GLOBALDATA::saveToFile(ofstream &ofsFile, bool aIsSaveGame)
-{
-  bool bResult = true;
-
-  // First: Write Global identifier:
-  bResult = pushData(FILEPART_GLOBALS, ofsFile);
-
-  if (bResult)
-    {
-      // Now changed screen dimensions can be applied for the next load
-      screenWidth = (int) temp_screenWidth;
-      screenHeight = (int) temp_screenHeight;
-    }
-
-  // Now we can push everything into the file:
-  // numPlayers isn't saved, it's dynamic!
-  if (bResult) bResult = pushData("Dither Gradient   ", ditherGradients,        ofsFile);
-  if (bResult) bResult = pushData("Detail Landscape  ", detailedLandscape,      ofsFile);
-  if (bResult) bResult = pushData("Detail Sky        ", detailedSky,            ofsFile);
-  if (bResult) bResult = pushData("Interest          ", interest,               ofsFile);
-  if (bResult) bResult = pushData("Score Round Win   ", scoreRoundWinBonus,     ofsFile);
-  if (bResult) bResult = pushData("Score Unit Hit    ", scoreHitUnit,           ofsFile);
-  if (bResult) bResult = pushData("Score Unit Destroy", scoreUnitDestroyBonus,  ofsFile);
-  if (bResult) bResult = pushData("Score Self Destroy", scoreUnitSelfDestroy,   ofsFile);
-  if (bResult) bResult = pushData("Sell Ratio        ", sellpercent,            ofsFile);
-  if (!aIsSaveGame)
-    {
-      // The following options are not saved in save games:
-      if (bResult) bResult = pushData("Start Money       ", startmoney,             ofsFile);
-      if (bResult) bResult = pushData("Turn Type         ", turntype,               ofsFile);
-      if (bResult) bResult = pushData("Skip Computer Play", skipComputerPlay,       ofsFile);
-      if (bResult) bResult = pushData("Sound             ", sound,                  ofsFile);
-      if (bResult) bResult = pushData("Screen Width      ", screenWidth,            ofsFile);
-      if (bResult) bResult = pushData("Screen Height     ", screenHeight,           ofsFile);
-      if (bResult) bResult = pushData("OS Mouse          ", os_mouse,               ofsFile);
-      if (bResult) bResult = pushData("Permanent Players ", numPermanentPlayers,    ofsFile);
-      if (bResult) bResult = pushData("Language          ", language,               ofsFile);
-      if (bResult) bResult = pushData("Color Theme       ", colour_theme,           ofsFile);
-      if (bResult) bResult = pushData("Frames Per Second ", frames_per_second,      ofsFile);
-      if (bResult) bResult = pushData("Violent Death     ", violent_death,          ofsFile);
-      if (bResult) bResult = pushData("Max Fire Time     ", max_fire_time,          ofsFile);
-    }
-  if (bResult) bResult = pushData(FILEPART_ENDSECT, ofsFile);
-  return(bResult);
-}
-
 int GLOBALDATA::saveToFile_Text( FILE *file)
 {
   if (! file) return FALSE;
@@ -213,6 +225,13 @@ int GLOBALDATA::saveToFile_Text( FILE *file)
   fprintf (file, "FRAMES=%f\n", frames_per_second);
   fprintf (file, "VIOLENTDEATH=%f\n", violent_death);
   fprintf (file, "MAXFIRETIME=%f\n", max_fire_time);
+  fprintf (file, "DIVIDEMONEY=%f\n", divide_money);
+  fprintf (file, "CHECKUPDATES=%f\n", check_for_updates);
+  fprintf (file, "NETWORKING=%f\n", enable_network);
+  fprintf (file, "LISTENPORT=%f\n", listen_port);
+  fprintf (file, "SOUNDDRIVER=%f\n", sound_driver);
+  fprintf (file, "PLAYMUSIC=%f\n", play_music);
+  fprintf (file, "FULLSCREEN=%f\n", full_screen);
   fprintf (file, "***\n");
   return TRUE;
 }
@@ -264,6 +283,11 @@ int GLOBALDATA::loadFromFile(ifstream &ifsFile)
       else if (!strcmp(chArea, "Frames Per Second ")) bResult = popData(frames_per_second,      ifsFile);
       else if (!strcmp(chArea, "Violent Death     ")) bResult = popData(violent_death,          ifsFile);
       else if (!strcmp(chArea, "Max Fire Time     ")) bResult = popData(max_fire_time,          ifsFile);
+      else if (!strcmp(chArea, "Divide Money      ")) bResult = popData(divide_money,           ifsFile);
+      else if (!strcmp(chArea, "Check Updates     ")) bResult = popData(check_for_updates,      ifsFile);
+      else if (!strcmp(chArea, "Networking        ")) bResult = popData(enable_network,         ifsFile);
+      else if (!strcmp(chArea, "Listen Port       ")) bResult = popData(listen_port,            ifsFile);
+      else if (!strcmp(chArea, "Sound Driver      ")) bResult = popData(sound_driver,           ifsFile);
       else if (!bIsFinished && bIsData)
         bResult = popData(dData, ifsFile); // Something we do not know (any more/yet), so dump it!
     }
@@ -388,6 +412,21 @@ int GLOBALDATA::loadFromFile_Text (FILE *file)
                 sscanf(value, "%lf", &violent_death);
               else if (! strcasecmp(field, "maxfiretime") )
                 sscanf(value, "%lf", &max_fire_time);
+              else if (! strcasecmp(field, "dividemoney") )
+                sscanf(value, "%lf", &divide_money);
+              else if (!strcasecmp(field, "checkupdates")) 
+                sscanf(value, "%lf", &check_for_updates);
+              else if (!strcasecmp(field, "networking"))
+                sscanf(value, "%lf", &enable_network);
+              else if (!strcasecmp(field, "listenport"))
+                sscanf(value, "%lf", &listen_port);
+              else if (!strcasecmp(field, "sounddriver"))
+                sscanf(value, "%lf", &sound_driver);
+              else if (!strcasecmp(field, "playmusic"))
+                sscanf(value, "%lf", &play_music);
+              else if (!strcasecmp(field, "fullscreen"))
+                sscanf(value, "%lf", &full_screen);
+      
             }    // end of found field=value line
 
         }     // end of read a line properly
@@ -458,7 +497,7 @@ void GLOBALDATA::removePlayer (PLAYER *player)
             }
         }
       else
-        // Position found, now move the remaining players down!
+        // Position found,1G now move the remaining players down!
         toCount = fromCount;
       fromCount++;
     }
@@ -486,13 +525,13 @@ PLAYER *GLOBALDATA::createNewPlayer (ENVIRONMENT *env)
   else
     {
       perror ( (char *)"atanks.cc: Failed allocating memory for reallocatedPlayers in GLOBALDATA::createNewPlayer");
-      exit (1);
+      // exit (1);
     }
   player = new PLAYER (this, env);
   if (!player)
     {
       perror ( (char *)"globaldata.cc: Failed allocating memory for player in GLOBALDATA::createNewPlayer");
-      exit (1);
+      // exit (1);
     }
   allPlayers[numPermanentPlayers] = player;
   numPermanentPlayers++;
@@ -541,7 +580,7 @@ char *GLOBALDATA::Get_Config_Path()
 
 
 
-// Thisa function checks to see if one full second has passed since the
+// This function checks to see if one full second has passed since the
 // last time the function was called.
 // The function returns true if time has passed. The function
 // returns false if time hasn't passed or it was unable to tell
@@ -560,3 +599,374 @@ bool GLOBALDATA::Check_Time_Changed()
   return true;
 }
 
+
+
+/*
+ * This function Loads a music file (if there is one available.
+ * A pointer to the music file is returned. If no music can
+ * be found, then NULL is returned.
+*/
+SAMPLE *GLOBALDATA::Load_Background_Music()
+{
+    SAMPLE *my_sample = NULL;;
+    struct dirent *folder_entry;
+
+    // see if we should bother
+    if (! play_music)
+       return NULL;
+
+    // see if we have the music folder open
+    if (! music_dir)
+    {
+        char *buffer = (char *) calloc( strlen(configDir) + 32, sizeof(char) );
+        if (! buffer)
+           return NULL;
+
+        sprintf(buffer, "%s/music", configDir);
+        music_dir = opendir(buffer);
+        free(buffer);
+        if (! music_dir)
+           return NULL;
+    }
+
+    // at this point we should have an open music folder
+    // the music folder is closed by global's deconstructor
+    // search for files ending in .wav
+    folder_entry = readdir(music_dir);
+    while ( (folder_entry) && (! my_sample) )
+    {
+        // we have something, see if it is a wav file
+        if ( strstr(folder_entry->d_name, ".wav") )
+        {
+            char *filename = (char *) calloc( strlen(configDir) + strlen(folder_entry->d_name) + 64, sizeof(char));
+            if (filename)
+            {
+               sprintf(filename, "%s/music/%s", configDir, folder_entry->d_name);
+               my_sample = load_sample(filename);
+               free(filename);
+            }
+        }
+        if (! my_sample)
+           folder_entry = readdir(music_dir);
+    }
+
+    if (! folder_entry)  // hit end of folder
+    {
+       closedir(music_dir);
+       music_dir = NULL;
+    }
+
+    return my_sample;
+}
+
+
+
+
+/*
+ * This function sets all variables, which get written to the
+ * config file, back to their defaults.
+ * -- Jesse
+ *  */
+void GLOBALDATA::Reset_Options()
+{
+  ditherGradients = 1;
+  detailedLandscape = 0;
+  detailedSky = 0;
+  interest = 1.25;
+  scoreRoundWinBonus = 10000;
+  scoreHitUnit = 75;
+  scoreUnitDestroyBonus = 5000;
+  scoreUnitSelfDestroy = 0;
+  sellpercent = 0.80;
+  startmoney = 15000;
+  turntype = TURN_RANDOM;
+  skipComputerPlay = SKIP_HUMANS_DEAD;
+  sound = 1.0;
+  screenWidth = DEFAULT_SCREEN_WIDTH;
+  screenHeight = DEFAULT_SCREEN_HEIGHT;
+  os_mouse = 1.0;
+  language = LANGUAGE_ENGLISH;
+  colour_theme = COLOUR_THEME_CRISPY;
+  frames_per_second = FRAMES_PER_SECOND;
+  violent_death = FALSE;
+  max_fire_time = 0.0;
+  divide_money = 0.0;
+  check_for_updates = 1.0;
+  enable_network = 0.0;
+  #ifdef NETWORK
+  listen_port = DEFAULT_LISTEN_PORT;
+  #endif
+  play_music = 1.0;
+} 
+
+
+
+
+/*
+ * This function loads all sounds from the data folder and saves them
+ * in an array.
+ * The function returns TRUE on success or FALSE if an error happens.
+*/
+int GLOBALDATA::Load_Sounds()
+{
+   int file_count = 0, array_size = 10;
+   char *file_name;
+   FILE *my_file;
+   SAMPLE *temp_sample;
+
+   file_name = (char *) calloc( strlen(dataDir) + 128, sizeof(char) );
+   if (! file_name)
+     return FALSE;
+
+   // allocate space for sound samples
+   sounds = (SAMPLE **) calloc(10, sizeof(SAMPLE *) );
+   if (! sounds)
+   {
+       free(file_name);
+       printf("Unable to create sound array.\n");
+       return FALSE;
+   }
+
+   // read from directory
+   sprintf(file_name, "%s/sound/%d.wav", dataDir, file_count);
+   my_file = fopen(file_name, "r");
+   while ( (my_file) && (sounds) )
+   {
+       fclose(my_file);
+       temp_sample = load_sample(file_name);
+       if (! temp_sample )
+         printf("An error occured loading sound file %s\n", file_name);
+       sounds[file_count] = temp_sample;
+       file_count++; 
+   
+       // make sure we have enough memory for more samples
+       if (file_count >= array_size)
+       {
+            array_size += 10;
+            sounds = (SAMPLE**) realloc(sounds, sizeof(SAMPLE*) * (array_size + 1));
+            if (! sounds)
+              printf("We just ran out of memory loading sound files.\n");
+            else
+            {
+              // zero out new memory pointers
+              int counter;
+              for (counter = file_count; counter <= array_size; counter++)
+                 sounds[counter] = NULL;
+            }
+       }
+       sprintf(file_name, "%s/sound/%d.wav", dataDir, file_count);
+       my_file = fopen(file_name, "r");
+   }
+
+   free(file_name);
+   return TRUE;
+}
+
+
+
+/*
+ * This function loads all the bitmaps needed by th game.
+ * Bitmaps are found in a series of sub-folders under the
+ * dataDir. The function returns TRUE on success and FALSE
+ * if an error occures.
+*/
+int GLOBALDATA::Load_Bitmaps()
+{
+   int file_group = 0;
+   int array_size, file_count;
+   char *file_name;
+   char sub_folder[64];
+   FILE *my_file;
+   BITMAP *new_bitmap, **bitmap_array;
+
+   file_name = (char *) calloc( strlen(dataDir) + 128, sizeof(char) );
+   if (!file_name)
+      return FALSE;
+
+   while (file_group < 7)
+   {
+     // set the folder we're looking at
+     switch (file_group)
+     {
+        case 0: strcpy(sub_folder, "title"); break;
+        case 1: strcpy(sub_folder, "button"); break;
+        case 2: strcpy(sub_folder, "misc"); break;
+        case 3: strcpy(sub_folder, "missile"); break;
+        case 4: strcpy(sub_folder, "stock"); break;
+        case 5: strcpy(sub_folder, "tank"); break;
+        case 6: strcpy(sub_folder, "tankgun"); break;
+     }
+
+     // set up empty array
+     array_size = 10;
+     bitmap_array = (BITMAP **) calloc(10, sizeof(BITMAP *) );
+     if (! bitmap_array)
+     {
+         printf("Ran out of memory, loading bitmaps.\n");
+         free(file_name);
+         return FALSE;
+     }
+
+     // search for files
+     file_count = 0;
+     sprintf(file_name, "%s/%s/%d.bmp", dataDir, sub_folder, file_count);
+     my_file = fopen(file_name, "r");
+     while ( (my_file) && (bitmap_array) )
+     {
+         fclose(my_file);
+         new_bitmap = load_bitmap(file_name, NULL);
+         if (! new_bitmap)
+           printf("An error occured loading bitmap %s\n", file_name);
+         bitmap_array[file_count] = new_bitmap;
+         file_count++;
+
+         // make sure array is large enough
+         if ( file_count >= array_size)
+         {
+            array_size += 10;
+            bitmap_array = (BITMAP **) realloc(bitmap_array, sizeof(BITMAP *) * (array_size + 1) );
+            if (! bitmap_array)
+               printf("Unable to increase array size while loading bitmaps.\n");
+            else
+            {
+               // clear memory
+               int count;
+               for (count = file_count; count <= array_size; count++)
+                  bitmap_array[count] = NULL;
+            }
+         }
+
+         // get next file
+         sprintf(file_name, "%s/%s/%d.bmp", dataDir, sub_folder, file_count);
+         my_file = fopen(file_name, "r");
+     }
+ 
+     // save the new array
+     switch (file_group)
+     {
+        case 0: title = bitmap_array; break;
+        case 1: button = bitmap_array; break;
+        case 2: misc = bitmap_array; break;
+        case 3: missile = bitmap_array; break;
+        case 4: stock = bitmap_array; break;
+        case 5: tank = bitmap_array; break;
+        case 6: tankgun = bitmap_array; break;
+     }
+
+     file_group++;
+   }
+
+   free(file_name);
+   return TRUE;
+}
+
+
+
+// This file loads in extra fonts the game requires.
+// Fonts should be stored in the datafolder. On
+// success the function returns TRUE. When an
+// error occures, it returns FALSE.
+int GLOBALDATA::Load_Fonts()
+{
+   char *filename;
+
+   filename = (char *) calloc( strlen(dataDir) + 32, sizeof(char));
+   if (!filename)
+     return FALSE;
+
+   sprintf(filename, "%s/unicode.dat", dataDir);
+   unicode = load_font(filename, NULL, NULL);
+   if (! unicode)
+      printf("Unable to load font %s\n", filename);
+   free(filename);
+
+   if (unicode)
+   {
+      Change_Font();
+      return TRUE;
+   }
+   else return FALSE;  
+}
+
+
+// This function selects the font to use. This should be called
+// right after a language change.
+void GLOBALDATA::Change_Font()
+{
+    FONT *temp_font = font;
+
+    if (language == LANGUAGE_RUSSIAN)
+       font = unicode;
+    else
+       font = regular_font;
+
+    if (temp_font != font)     // font has changed
+    {
+       Load_Weapons_Text(this);
+       Load_Text_Files();
+    }
+}
+
+
+
+
+// This function loads all needed text files, based on
+// language, into memory. If a previous text was loaded, it is
+// removed from memory first.
+int GLOBALDATA::Load_Text_Files()
+{
+    char *filename;
+    char suffix[32];
+
+    filename = (char *) calloc( strlen(dataDir) + 64, sizeof(char) );
+    if (! filename)
+       return FALSE;
+
+    if (war_quotes) delete war_quotes;
+    if (instructions) delete instructions;
+    if (gloat) delete gloat;
+    if (revenge) delete revenge;
+    if (retaliation) delete retaliation;
+    if (suicide) delete suicide;
+    if (kamikaze) delete kamikaze;
+    if (ingame) delete ingame;
+
+    if (language == LANGUAGE_RUSSIAN)
+       sprintf(filename, "%s/text/war_quotes_ru.txt", dataDir);
+    else
+       sprintf(filename, "%s/text/war_quotes.txt", dataDir);
+    war_quotes = new TEXTBLOCK(filename);
+
+     if (language == LANGUAGE_PORTUGUESE)
+        strcpy(suffix, ".pt_BR.txt");
+     else if (language == LANGUAGE_FRENCH)
+        strcpy(suffix, "_fr.txt");
+     else if (language == LANGUAGE_GERMAN)
+        strcpy(suffix, "_de.txt");
+     else if (language == LANGUAGE_SLOVAK)
+        strcpy(suffix, "_sk.txt");
+     else if (language == LANGUAGE_RUSSIAN)
+        strcpy(suffix, "_ru.txt");
+     else
+        strcpy(suffix, ".txt");       // default to english
+
+    sprintf(filename, "%s/text/instr%s", dataDir, suffix);
+    instructions = new TEXTBLOCK(filename);
+
+    sprintf(filename, "%s/text/gloat%s", dataDir, suffix);
+    gloat = new TEXTBLOCK(filename);
+    sprintf(filename, "%s/text/revenge%s", dataDir, suffix);
+    revenge = new TEXTBLOCK(filename);
+    sprintf(filename, "%s/text/retaliation%s", dataDir, suffix);
+    retaliation = new TEXTBLOCK(filename);
+    sprintf(filename, "%s/text/suicide%s", dataDir, suffix);
+    suicide = new TEXTBLOCK(filename);
+    sprintf(filename, "%s/text/kamikaze%s", dataDir, suffix);
+    kamikaze = new TEXTBLOCK(filename);
+    sprintf(filename, "%s/text/ingame%s", dataDir, suffix);
+    ingame = new TEXTBLOCK(filename);
+
+    free(filename);
+    return TRUE;
+}
+
