@@ -19,8 +19,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * */
 
+#include <sys/types.h>
+#include <dirent.h>
 
 #include "main.h"
+#include "text.h"
 
 #define DEFAULT_SCREEN_WIDTH 800
 #define DEFAULT_SCREEN_HEIGHT 600
@@ -30,6 +33,7 @@
 #define LANGUAGE_FRENCH 2.0
 #define LANGUAGE_GERMAN 3.0
 #define LANGUAGE_SLOVAK 4.0
+#define LANGUAGE_RUSSIAN 5.0
 
 #define COLOUR_THEME_REGULAR 0.0
 #define COLOUR_THEME_CRISPY 1.0
@@ -44,6 +48,24 @@
 #define MAX_INTEREST_AMOUNT 100000
 #define MAX_TEAM_AMOUNT 500000
 
+#define DEMO_WAIT_TIME 60
+
+#define SOUND_AUTODETECT 0
+#define SOUND_OSS 1
+#define SOUND_ESD 2
+#define SOUND_ARTS 3
+#define SOUND_ALSA 4
+#define SOUND_JACK 5
+
+#define FULL_SCREEN_EITHER 10.0
+#define FULL_SCREEN_TRUE  1.0
+#define FULL_SCREEN_FALSE 0.0
+
+#define MAX_AI_TIME 10
+
+#define ALL_SOCKETS -1
+
+
 enum skipComputerPlayType
 {
   SKIP_NONE, SKIP_HUMANS_DEAD// , SKIP_AUTOPLAY
@@ -54,18 +76,9 @@ class TANK;
 class GLOBALDATA
   {
   private:
-    // copy-ctor and assign operator are private, so the compiler won't create implicit ones!
-    inline GLOBALDATA (GLOBALDATA &sourceGlobal _UNUSED) {  }
-    inline const GLOBALDATA& operator= (const GLOBALDATA &sourceGlobal) { return(sourceGlobal); }
-
+  DIR *music_dir;
   public:
-    inline ~GLOBALDATA()
-      {
-        if (tank_status)
-          free(tank_status);
-        tank_status[0] = 0x0;
-      }
-
+    ~GLOBALDATA();
     int	WHITE, BLACK, PINK;
     double	slope[360][2];
 
@@ -99,12 +112,15 @@ class GLOBALDATA
     int	halfWidth, halfHeight;
     int     width_override, height_override;
     double  temp_screenWidth, temp_screenHeight;
+    PLAYER *client_player;     // the index we use to know which one is the player on the client side
     gfxDataStruct	gfxData;
-    DATAFILE	*SOUND;
+    // DATAFILE	*SOUND;
+    ENVIRONMENT *env;
 
-    bool            full_screen;
+    // bool            full_screen;
     int		cacheCirclesBG ;	/* This is just a flag, so it need only be
 								an integer, not a double */
+    void Reset_Options();
 
     /* Logically, these three variables should be ints.  However, converting
     them to ints (or even an enumerated type) would require some rewritting
@@ -115,6 +131,7 @@ class GLOBALDATA
     double detailedSky;
     double os_mouse;          // whether we should use the OS or custom mouse
     double colour_theme;     // land and sky gradiant theme
+    double sound_driver;
 
     /* All this money data; couldn't it be moved into some separate data
     structure or object */
@@ -127,6 +144,10 @@ class GLOBALDATA
     double	scoreUnitSelfDestroy;
     double	scoreRoundWinBonus;
     double  sellpercent;
+    double  divide_money;
+    double  play_music;
+    double full_screen;
+    char server_name[128], server_port[128];
 
     /* double? */
     /* double for options() reasons, no messing about with casting or
@@ -138,7 +159,7 @@ class GLOBALDATA
     double  language;
     int     name_above_tank;
     int     tank_status_colour;
-    char  * tank_status;
+    char   *tank_status;
     char    game_name[GAME_NAME_LENGTH];
     double  load_game;
     double  campaign_mode;
@@ -147,13 +168,23 @@ class GLOBALDATA
     char    **saved_game_list;
     double  max_fire_time;
     bool close_button_pressed;
+    char *update_string;
+    double check_for_updates;
+    bool demo_mode;
+    double enable_network, listen_port;
+    int draw_background;
+    BITMAP **button, **misc, **missile, **stock, **tank, **tankgun, **title;
+    SAMPLE **sounds;
+    SAMPLE *background_music;
+    FONT *unicode, *regular_font;
+    TEXTBLOCK *war_quotes, *instructions, *ingame;
+    TEXTBLOCK *gloat, *revenge, *retaliation, *suicide, *kamikaze;
 
     GLOBALDATA ();
     void	initialise ();
     int     saveToFile_Text (FILE *file);
-    int     saveToFile (ofstream &ofsFile, bool aIsSaveGame = false);
     int     loadFromFile_Text (FILE *file);
-    int     loadFromFile (ifstream &ifsFile);
+    int     loadFromFile(ifstream &my_file);
     void	addPlayer (PLAYER *player);
     void	removePlayer (PLAYER *player);
     PLAYER	*getNextPlayer (int *playerCount);
@@ -165,6 +196,12 @@ class GLOBALDATA
     bool		bIsBoxed;
     int			iHumanLessRounds;
     double	dMaxVelocity;
+    int Load_Sounds();
+    int Load_Bitmaps();
+    SAMPLE *Load_Background_Music();
+    int Load_Fonts();
+    void Change_Font();
+    int Load_Text_Files();
 #ifdef DEBUG_AIM_SHOW
     bool bASD;
 #endif
