@@ -21,7 +21,7 @@
  * */
 
 #ifndef VERSION
-#define VERSION "3.6"
+#define VERSION "4.1"
 #endif
 
 #ifdef GENTOO
@@ -30,6 +30,9 @@
 #endif
 #endif
 
+#ifndef BUFFER_SIZE
+#define BUFFER_SIZE 256
+#endif
 
 #ifndef _UNUSED
 #define _UNUSED __attribute__ ((unused))
@@ -61,11 +64,13 @@
 #ifdef LINUX
 #define LINUX_SLEEP usleep(10000)
 #define LINUX_REST usleep(40000)
+#define LINUX_DREAMLAND sleep(5)
 #else
 #include <windows.h>
 #include <winbase.h>
 #define LINUX_SLEEP Sleep(10)
 #define LINUX_REST Sleep(40)
+#define LINUX_DREAMLAND Sleep(500)
 #endif
 
 using namespace std;
@@ -111,10 +116,10 @@ using namespace std;
 #define LANDS 8
 #define ALL_SKIES 16
 #define ALL_LANDS 16
-#define	BALLISTICS 45
+#define	BALLISTICS 52
 #define	BEAMWEAPONS 3
 #define WEAPONS (BALLISTICS + BEAMWEAPONS)
-#define ITEMS 21
+#define ITEMS 24
 #define THINGS (WEAPONS + ITEMS)
 #define	NATURALS 6
 #define RADII 6
@@ -124,10 +129,10 @@ using namespace std;
 #define	DISPERSEFRAMES 10
 #define	EXPLOSIONFRAMES	(EXPLODEFRAMES + DISPERSEFRAMES)
 #define TANKSAG 10
-#define MENUBUTTONS 6
+#define MENUBUTTONS 7
 #define MISSILEFRAMES 1
 #define ACHANGE 256/360
-#define INGAMEBUTTONS 3
+#define INGAMEBUTTONS 4
 #define MAX_MISSILES 10
 #define SPREAD 10
 #define SHIELDS 6
@@ -150,6 +155,9 @@ using namespace std;
 // bitmaps for tanks
 #define NORMAL_TANK 0
 #define CLASSIC_TANK 1     // really 8 in the .dat file
+#define BIGGREY_TANK 2
+#define T34_TANK 3
+
 
 // background images
 #define BACKGROUND_CIRCLE 0
@@ -174,13 +182,6 @@ enum turnTypes
   TURN_HIGH, TURN_LOW, TURN_RANDOM, TURN_SIMUL
 };
 
-//options
-//#define	OPT_GRAVITY		0
-//#define	OPT_WINDSTRENGTH	1
-//#define	OPT_WINDVARIATION	2
-//#define	OPT_STARTMONEY		3
-//#define	OPT_TURNTYPE		4
-
 class BOX
   {
   public:
@@ -198,18 +199,18 @@ class WEAPON
   {
   public:
     char		name[128];		//name of weapon
-    char		description[256];
+    char		description[512];
     int             cost;		//$ :))
-    int		amt;		//number of weapons in one package
+    int		amt;		//number of weapons in one buying package
     double		mass;
     double		drag;
-    int		radius;
+    int		radius;        // of the explosion
     int		sound;
     int		etime;
     int		damage;		//damage power
     int		eframes;
-    int		picpoint;
-    int		spread;
+    int		picpoint;       // which picture do we show in flight?
+    int		spread;         // number of weapons in the shot
     int		delay;		// volleys etc.
     int		noimpact;
     int		techLevel;
@@ -265,7 +266,7 @@ enum weaponType
 {
   SML_MIS, MED_MIS, LRG_MIS, SML_NUKE, NUKE, DTH_HEAD,
   SML_SPREAD, MED_SPREAD, LRG_SPREAD, SUP_SPREAD, DTH_SPREAD, ARMAGEDDON,
-  CHAIN_MISSILE,
+  CHAIN_MISSILE, CHAIN_GUN, JACK_HAMMER,
   SHAPED_CHARGE, WIDE_BOY, CUTTER,
   SML_ROLLER, LRG_ROLLER, DTH_ROLLER,
   SMALL_MIRV,
@@ -277,22 +278,29 @@ enum weaponType
   BURROWER, PENETRATOR,
   SML_NAPALM, MED_NAPALM, LRG_NAPALM,
   NAPALM_JELLY,
+  DRILLER,
   TREMOR, SHOCKWAVE, TECTONIC,
   RIOT_BOMB, HVY_RIOT_BOMB,
   RIOT_CHARGE, RIOT_BLAST,
   DIRT_BALL, LRG_DIRT_BALL, SUP_DIRT_BALL,
-  SML_LAZER, MED_LAZER, LRG_LAZER,
+  SMALL_DIRT_SPREAD,
+  CLUSTER_MIRV,
+  PERCENT_BOMB,
+  REDUCER,
+  SML_LAZER, MED_LAZER, LRG_LAZER, 
   SML_METEOR, MED_METEOR, LRG_METEOR,
   SML_LIGHTNING, MED_LIGHTNING, LRG_LIGHTNING
 };
 
-#define LAST_EXPLOSIVE	NAPALM_JELLY
+// #define LAST_EXPLOSIVE	NAPALM_JELLY
+#define LAST_EXPLOSIVE DRILLER
 
 #define ITEM_NO_SHIELD			-1
 enum itemType
 {
   ITEM_TELEPORT,
   ITEM_SWAPPER,
+  ITEM_MASS_TELEPORT,
   ITEM_FAN,
   ITEM_VENGEANCE,
   ITEM_DYING_WRATH,
@@ -311,7 +319,9 @@ enum itemType
   ITEM_DIMPLEP,
   ITEM_PARACHUTE,
   ITEM_REPAIRKIT,
-  ITEM_FUEL
+  ITEM_FUEL,
+  ITEM_ROCKET,
+  ITEM_SDI
 };
 
 #define SHIELD_COUNT		6
@@ -326,6 +336,9 @@ enum itemType
 #define GLOBAL_COMMAND_CREDITS		 3
 #define	GLOBAL_COMMAND_HELP		     4
 #define GLOBAL_COMMAND_PLAY        5
+#define GLOBAL_COMMAND_DEMO        6
+#define GLOBAL_COMMAND_NETWORK     7
+
 
 // Classes
 #define	ANY_CLASS		-1
@@ -342,8 +355,8 @@ enum itemType
 
 typedef struct
   {
-    DATAFILE	*M, *T, *TITLE, *S, *E, *B, *L,
-    *TG, *MI, *STOCK_IMAGE;
+    // DATAFILE	*M, *T, *TITLE, *S, *E, *B, *L,
+    // *TG, *MI, *STOCK_IMAGE;
 
     BITMAP		*sky_gradient_strips[ALL_SKIES];
     BITMAP		*land_gradient_strips[ALL_LANDS];
@@ -392,7 +405,7 @@ bool loadPlayers(GLOBALDATA *global, ENVIRONMENT *env, ifstream &ifsFile) _WARNU
 // save all game settings
 bool Save_Game_Settings(GLOBALDATA *global, ENVIRONMENT *env, char *text_file, bool bIsSaveGame = false) _WARNUNUSED;
 bool savePlayers (GLOBALDATA *global, ofstream &ofsFile) _WARNUNUSED;
-//int Save_Game_Settings_Text(GLOBALDATA *global, ENVIRONMENT *env, char *path_to_file);
+int Save_Game_Settings_Text(GLOBALDATA *global, ENVIRONMENT *env, char *path_to_file);
 
 // These defines are needed to identify parts of the binary save files.
 #define FILEPART_ENVIRON "[Environment]"
@@ -405,6 +418,7 @@ bool savePlayers (GLOBALDATA *global, ofstream &ofsFile) _WARNUNUSED;
 // methods to handle loading and saving of data
 
 /*  --- take data out of filestream -- */
+bool popColo(int    &aData, ifstream &ifsFile) _WARNUNUSED;
 bool popData(int    &aData, ifstream &ifsFile) _WARNUNUSED;
 bool popData(double &aData, ifstream &ifsFile) _WARNUNUSED;
 bool popData(char  * aArea, bool &aIsData, ifstream &ifsFile) _WARNUNUSED;
@@ -415,6 +429,7 @@ bool popData(char  * aArea, bool &aIsData, ifstream &ifsFile) _WARNUNUSED;
 /*  --- put data into filestream -- */
 //bool pushData(const int     aData, ofstream &ofsFile) _WARNUNUSED;
 //bool pushData(const double  aData, ofstream &ofsFile) _WARNUNUSED;
+bool pushColo(const char  * aArea, const int    aData, ofstream &ofsFile) _WARNUNUSED;
 bool pushData(const char  * aData, ofstream &ofsFile) _WARNUNUSED;
 bool pushData(const char  * aArea, const int    aData, ofstream &ofsFile) _WARNUNUSED;
 //bool pushName(const char  * aData, ofstream &ofsFile) _WARNUNUSED; // Special function for name saving
@@ -428,7 +443,7 @@ bool pushData(const char  * aArea, const double aData, ofstream &ofsFile) _WARNU
 int Change_Settings(double old_mouse, double old_sound, double new_mouse, double new_sound, void *mouse_image);
 
 int *Sort_Scores(GLOBALDATA *global);
-
+int Game_Client(GLOBALDATA *global, ENVIRONMENT *env, int socket_number);
 
 #include "externs.h"
 
