@@ -60,7 +60,7 @@ MISSILE::MISSILE (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos
   picpoint = weap->picpoint;
   noimpact = weap->noimpact;
   countdown = -1;
-  _bitmap = (BITMAP *)_global->gfxData.MI[picpoint].dat;
+  _bitmap = (BITMAP *)_global->missile[picpoint];
   physics = 0;
   age = 0;
   if (type >= SML_METEOR && type <= LRG_METEOR)
@@ -85,6 +85,18 @@ MISSILE::MISSILE (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos
      bIsGrowing = false;
      iGrowRadius= expSize;
     }
+  if ( (type == FUNKY_BOMBLET) || (type == FUNKY_DEATHLET) )
+  {
+      int temp_number = rand() % 5;
+      switch (temp_number)
+      {
+         case 0: funky_colour = makecol(200, 0, 0); break;
+         case 1: funky_colour = makecol(0, 200, 0); break;
+         case 2: funky_colour = makecol(0, 0, 200); break;
+         case 3: funky_colour = makecol(200, 200, 0); break;
+         case 4: funky_colour = makecol(200, 0, 200); break;
+      }
+  }
 }
 
 void MISSILE::initialise ()
@@ -104,20 +116,6 @@ void MISSILE::initialise ()
     }
 }
 
-/*
-void MISSILE::explode ()
-{
-	EXPLOSION *explosion;
-
-	explosion = new EXPLOSION (_global, _env, x, y, type);
-	if (!explosion) {
-		perror ( (char *)"missile.cc: Failed allocating memory for explosion in MISSILE::explode");
-		exit (1);
-	}
-	explosion->player = player;
-	destroy = TRUE;
-}
-*/
 
 
 int MISSILE::triggerTest ()
@@ -155,19 +153,26 @@ int MISSILE::triggerTest ()
               if (x > (_global->screenWidth - 2))
                 x = (_global->screenWidth - 2);
 
-              if	(	(y >= _env->surface[(int)x])				// y is surface or below
-                   &&(y <= _env->surface[(int)x] + 2) )  // but not burried more than 2 px
+              if ( (y >= _env->surface[(int)x])       // y is surface or below
+                   && (y <= _env->surface[(int)x] + 2) )  // but not burried more than 2 px
                 y = _env->surface[(int)x] - 1;
 
               yv = 0.0;
-              if (xv > 0.0) yv = 1.0;
-              if (xv < 0.0) yv =-1.0;
+              // if (xv > 0.0) yv = 1.0;
+              // if (xv < 0.0) yv =-1.0;
 
               xv = 0.0;
+              if (x == 1)
+                  xv++;
+              else if (x == (_global->screenWidth - 2) )
+                  xv--;
+              else
+              {
               if (getpixel (_env->terrain, (int)x + 1, (int)y + 1) == PINK)
                 xv++;
               if (getpixel (_env->terrain, (int)x - 1, (int)y + 1) == PINK)
                 xv--;
+              }
               if (xv == 0.0)
                 // if both sides are free (should be impossible, but might be a 1-pixel-peak) the shooting direction decides
                 xv = yv;
@@ -257,19 +262,19 @@ int MISSILE::triggerTest ()
 
                   newmis = new MISSILE (_global, _env, x, y - 20, _global->slope[dAngle][0] * launchSpeed * (100.0 / _global->frames_per_second) + inheritedXV, _global->slope[dAngle][1] * launchSpeed * (100.0 / _global->frames_per_second) + inheritedYV, weap->submunition);
 
-                  if (!newmis)
-                    {
-                      perror ( (char *)"missile.cc: Failed allocating memory for newmis in MISSILE::triggerTest (CLUSTER)");
-                      exit (1);
-                    }
+                  if (newmis)
+                  {
 
-                  newmis->physics = submunitionPhys;
-                  newmis->player = player;
-                  newmis->countdown = newmisCount;
-                  newmis->noimpact = weapon[weap->submunition].noimpact;
-                  newmis->setUpdateArea
-                  ((int) newmis->x - 20,
-                   (int) newmis->y - 20, 40, 40);
+                      newmis->physics = submunitionPhys;
+                      newmis->player = player;
+                      newmis->countdown = newmisCount;
+                      newmis->noimpact = weapon[weap->submunition].noimpact;
+                      newmis->setUpdateArea
+                       ((int) newmis->x - 20,
+                       (int) newmis->y - 20, 40, 40);
+                  }
+                  else
+                      perror ( "missile.cc: Failed allocating memory for newmis in MISSILE::triggerTest (CLUSTER)");
                 }
             }
           destroy = TRUE;
@@ -353,7 +358,7 @@ int MISSILE::applyPhysics ()
         detonate = checkPixelsBetweenPrevAndNow ();
 
       // mirvs trigger above ground
-      if ( (! detonate) && (type == SMALL_MIRV) )
+      if ( (! detonate) && ( (type == SMALL_MIRV) || (type == CLUSTER_MIRV) ) )
         {
           above_ground = Height_Above_Ground();
           if ( (above_ground > 0) && (above_ground < TIGGER_HEIGHT) &&
@@ -380,8 +385,8 @@ int MISSILE::applyPhysics ()
           decor = new DECOR (_global, _env, x, y, xv, yv, expSize / 20, DECOR_SMOKE);
           if (!decor)
             {
-              perror ( (char *)"missile.cc: Failed allocating memory for decor in MISSILE::applyPhysics (METEOR)");
-              exit (1);
+              perror ( "missile.cc: Failed allocating memory for decor in MISSILE::applyPhysics (METEOR)");
+              // exit (1);
             }
         }
     }
@@ -390,38 +395,6 @@ int MISSILE::applyPhysics ()
       if (type >= SML_ROLLER && type <= DTH_ROLLER)
         {
           /* rollerupdate */
-// this was a bit too easy made and didn't take flat terrain into account!
-//          if (physics == 1)
-//            {
-//              // for (y = _global->screenHeight - 1; getpixel (_env->terrain, (int)x, (int)y) != PINK; y--);
-//              if (getpixel (_env->terrain, (int)x + 1, (int)y + 1) == PINK)
-//                physics = 3;
-//							else
-//                physics = 2;
-//            }
-//          if (physics == 2)
-//            x--, angle -= 3;
-//          if (physics == 3)
-//            x++, angle += 3;
-//          if ((y > MENUHEIGHT) && (	(physics == 4) || (x < 1) || (x > (_global->screenWidth-1))
-//																	||(y > _global->screenHeight - 1) || (getpixel (_env->terrain, (int)x, (int)y) != PINK))	)
-//            {
-//              detonate = 1;
-//
-//            }
-//          else
-//            {
-//              // roll roller
-//              y += 3;
-//              if	( (y > MENUHEIGHT)
-//									&&( (y > _global->screenHeight - 2)
-//										||(getpixel (_env->terrain, (int)x, (int)y) != PINK) ) )
-//                for (y = _global->screenHeight - 4; getpixel (_env->terrain, (int)x, (int)y + 3) != PINK; y--);
-//              if (angle < 0)
-//                angle += 256;
-//              if (angle > 255)
-//                angle -= 256;
-//            }
           // check whether we have hit anything
           if (	 (x < 1)
                 ||(x > (_global->screenWidth - 2))
@@ -588,17 +561,18 @@ void MISSILE::trigger ()
 
   if (type >= TREMOR && type <= TECTONIC)
     explosion = new EXPLOSION (_global, _env, x, y, xv, yv, type);
-  else if (type >= RIOT_CHARGE && type <= RIOT_BLAST)
+  else if (type >= RIOT_CHARGE && type <= RIOT_BLAST) 
     explosion = new EXPLOSION (_global, _env, x, y, xv, yv, type);
   else
     explosion = new EXPLOSION (_global, _env, x, y, type);
 
   if (!explosion)
     {
-      perror ( (char *)"missile.cc: Failed allocating memory for explosion in MISSILE::trigger");
-      exit (1);
+      perror ( "missile.cc: Failed allocating memory for explosion in MISSILE::trigger");
+      // exit (1);
     }
-  explosion->player = player;
+  else
+     explosion->player = player;
 
 
 
@@ -614,8 +588,8 @@ void MISSILE::trigger ()
             cSecondExplo = new EXPLOSION (_global, _env, _global->screenWidth + x, y, type);
           if (!cSecondExplo)
             {
-              perror ( (char *)"missile.cc: Failed allocating memory for cSecondExplo in MISSILE::trigger");
-              exit (1);
+              perror ( "missile.cc: Failed allocating memory for cSecondExplo in MISSILE::trigger");
+              // exit (1);
             }
         }
       if (x > (_global->screenWidth - weapon[type].radius))
@@ -627,8 +601,8 @@ void MISSILE::trigger ()
             cSecondExplo = new EXPLOSION (_global, _env, x - _global->screenWidth, y, type);
           if (!cSecondExplo)
             {
-              perror ( (char *)"missile.cc: Failed allocating memory for cSecondExplo in MISSILE::trigger");
-              exit (1);
+              perror ( "missile.cc: Failed allocating memory for cSecondExplo in MISSILE::trigger");
+              // exit (1);
             }
         }
       if (cSecondExplo)
@@ -639,9 +613,9 @@ void MISSILE::trigger ()
 
   destroy = TRUE;
 
-  if ((type >= DIRT_BALL && type <= SUP_DIRT_BALL) || (type >= RIOT_CHARGE && type <= RIOT_BLAST))
+  if ((type >= DIRT_BALL && type <= SMALL_DIRT_SPREAD) || (type >= RIOT_CHARGE && type <= RIOT_BLAST))
     {
-      play_sample ((SAMPLE *) _global->SOUND[9].dat, 128 + (expSize / 2), 128, 1000 - (expSize * 2), 0);
+      play_sample ((SAMPLE *) _global->sounds[9], 128 + (expSize / 2), 128, 1000 - (expSize * 2), 0);
     }
   else if (type == NAPALM_JELLY)
     {
@@ -649,7 +623,7 @@ void MISSILE::trigger ()
     }
   else
     {
-      play_sample ((SAMPLE *) _global->SOUND[WEAPONSOUNDS + sound].dat, 255, 128, 1000, 0);
+      play_sample ((SAMPLE *) _global->sounds[WEAPONSOUNDS + sound], 255, 128, 1000, 0);
     }
 }
 
@@ -657,13 +631,14 @@ void MISSILE::draw (BITMAP *dest)
 {
   if (!destroy)
     {
+      // draw missile if it is above the screen
       if (y < MENUHEIGHT)
         {
           BITMAP *bbitmap = _bitmap;
           double by = y;
           int bangle = angle;
 
-          _bitmap = (BITMAP*)_global->gfxData.M[3].dat;
+          _bitmap = (BITMAP*)_global->misc[3];
           y = (double)MENUHEIGHT + (_bitmap->h / 2);
           angle = 0;
 
@@ -672,6 +647,8 @@ void MISSILE::draw (BITMAP *dest)
           y = by;
           angle = bangle;
         }
+
+      // draw missile on the screen
       else
         {
 
@@ -679,7 +656,9 @@ void MISSILE::draw (BITMAP *dest)
             {
               if (bIsGrowing)
                 {
-                  circlefill (_env->db, (int)x, (int)y, iGrowRadius, makecol (255, 0, 0));
+                  circlefill (_env->db, (int)x, (int)y, iGrowRadius - 2, makecol (255, 0, 0));
+                  circle(_env->db, (int)x, (int)y, iGrowRadius - 1, makecol(255, 150, 0));
+                  circle(_env->db, (int)x, (int)y, iGrowRadius, makecol(255, 150, 0));
                   setUpdateArea ( (int)x - (iGrowRadius + 1),
                                   (int)y - (iGrowRadius + 1),
                                   (iGrowRadius + 1) * 2,
@@ -687,11 +666,23 @@ void MISSILE::draw (BITMAP *dest)
                 }
               else
                 {
-                  circlefill (_env->db, (int)x, (int)y, expSize, makecol (255, 0, 0));
+                  circlefill (_env->db, (int)x, (int)y, expSize - 2, makecol (255, 0, 0));
+                  circle(_env->db, (int)x, (int)y, expSize - 1, makecol(255, 150, 0));
+                  circle(_env->db, (int)x, (int)y, expSize, makecol(255, 150, 0));
                   setUpdateArea ((int)x - (expSize + 1), (int)y - (expSize + 1), (expSize + 1) * 2, (expSize + 1) * 2);
                 }
               requireUpdate ();
-            }
+            }   // end of napalm
+
+          // try drawing a funky bomblet
+          else if ( ( type == FUNKY_BOMBLET) || (type == FUNKY_DEATHLET) )
+          {
+              circlefill(_env->db, (int) x, (int) y, 4, funky_colour );
+              circle(_env->db, (int) x, (int) y, 5, makecol(0, 0, 0) );
+              setUpdateArea( (int) x - 10, (int) y - 10, 20, 20);
+              requireUpdate();
+          } 
+          // draw anything else, besides napalm
           else
             {
               VIRTUAL_OBJECT::draw (dest);
@@ -700,6 +691,18 @@ void MISSILE::draw (BITMAP *dest)
     }
 }
 
+
+void MISSILE::setEnvironment(ENVIRONMENT *env)
+    {
+      if (!_env || (_env != env))
+        {
+          _env = env;
+          _index = _env->addObject (this);
+        }
+    }
+
+
+
 int MISSILE::isSubClass (int classNum)
 {
   if (classNum == MISSILE_CLASS)
@@ -714,27 +717,56 @@ int MISSILE::isSubClass (int classNum)
 // the missile.
 int MISSILE::Height_Above_Ground()
 {
-  int pixel_colour;
   int height = (int)y + 1;
-  int found = FALSE;
 
   if (y < 0)
     return height;
 
-  // start from current position and move down
-  while ( (height < _global->screenHeight) && (! found) )
-    {
-      pixel_colour = getpixel (_env->terrain, (int)x, height);
-      // see if we hit ground
-      if (pixel_colour != PINK)
-        found = TRUE;
-      else
-        height++;
-    }
-
-  if (! found)
-    return 0;       // at ground level
-
-  return (height - (int)y);
+  height = _env->surface[(int) x] - y;
+  return height;
 }
 
+
+
+// Check to see if any tanks have SDI defense. If they
+// do, then see if this missile should be shot down.
+// Returns the shooting tank if a shot is to be fired
+// or NULL if no tank will shoot.
+TANK *MISSILE::Check_SDI(GLOBALDATA *global)
+{
+    TANK *my_tank;
+    int index;
+    double distance;
+    int chance;
+
+    if (type == NAPALM_JELLY)     // can't shoot jelly
+       return NULL;
+
+    for (index = 0; index < global->numPlayers; index++)
+    {
+        if ( ( global->players[index] ) && ( global->players[index]->tank) )
+        {
+            my_tank = global->players[index]->tank;
+            if ( (my_tank->player->ni[ITEM_SDI]) && (my_tank->player != this->player) )
+            {
+                 distance = pow(x - my_tank->x, 2);
+                 distance += pow(y - my_tank->y, 2);
+                 distance = sqrt(distance);
+                 // only fire if within range and above the tank
+                 if ( ( distance < SDI_DISTANCE ) && (my_tank->y > y) )
+                 {
+                      chance = rand() % 5;
+                      if (! chance)
+                      {
+                         return my_tank;
+                      }
+                 }        // within range
+            }      // we have SDI
+        }       // end of we have a valid player/tank
+       
+    }           // finished going through all players
+    
+    return NULL;
+}
+
+
