@@ -34,7 +34,8 @@ enum playerType
   TARGETTER_PLAYER,
   DEADLY_PLAYER,
   LAST_PLAYER_TYPE,
-  PART_TIME_BOT         // normally a human, but acting as a deadly computer
+  PART_TIME_BOT,         // normally a human, but acting as a deadly computer
+  NETWORK_CLIENT
 };
 //player weapon preference type
 //ALWAYS_PREF - only choose weapon preferences once on player creation
@@ -57,18 +58,12 @@ enum turnStages
 #define	MAX_WEAP_PROBABILITY	10000
 #define BURIED_LEVEL 135
 
+#define NET_COMMAND_SIZE 64
+
 
 class TANK;
 class PLAYER
   {
-  private:
-    // empty ctor, copy-ctor and assign operator are private, so the compiler won't create implicit ones!
-    inline PLAYER () { }
-    inline PLAYER (PLAYER &sourcePlayer _UNUSED) {  }
-    inline const PLAYER& operator= (const PLAYER &sourcePlayer)
-    {
-      return(sourcePlayer);
-    }
 
     char	_name[NAME_LENGTH];
     int	_currTank;
@@ -96,7 +91,6 @@ class PLAYER
     int getAdjustedTargetX(TANK * aTarget = NULL);
     int calculateAttack(TANK *aTarget = NULL);
     void calculateAttackValues(int &aDistanceX, int aDistanceY, int &aRawAngle, int &aAdjAngle, int &aPower, bool aAllowFlip);
-    int	calculateDirectAngle (int dx, int dy);
     int	traceShellTrajectory (double aTargetX, double aTargetY, double aVelocityX, double aVelocityY, double &aReachedX, double &aReachedY);
     int	rangeFind (int &aAngle, int &aPower);
 
@@ -104,7 +98,7 @@ class PLAYER
     double	type, type_saved;
     double preftype;
     char* preftypeText[ALWAYS_PREF + 1];
-    char *tank_type[2];
+    char *tank_type[4];
     char *teamText[3];
 
     PLAYER	*revenge;
@@ -139,6 +133,10 @@ class PLAYER
     double team;
     int time_left_to_fire;
     bool skip_me;
+    #ifdef NETWORK
+    int server_socket;
+    char net_command[NET_COMMAND_SIZE];
+    #endif
 
     PLAYER (GLOBALDATA *global, ENVIRONMENT *env);
     PLAYER (GLOBALDATA *global, ENVIRONMENT *env, ifstream &ifsFile, bool file); 
@@ -148,6 +146,7 @@ class PLAYER
     {
       return (_name);
     };
+    int	calculateDirectAngle (int dx, int dy);
     void	exitShop ();
     void	newRound ();
     void	initialise ();
@@ -165,13 +164,7 @@ class PLAYER
     void	generatePreferences ();
     void	setComputerValues (int aOffset = 0);
     int getMoneyToSave();
-    inline int getBoostValue()
-    {
-      return ((int)(ni[ITEM_ARMOUR] * ((double) item[ITEM_ARMOUR].vals[0] / (double) item[ITEM_PLASTEEL].vals[0])) +
-              ni[ITEM_PLASTEEL] +
-              (int)(ni[ITEM_INTENSITY_AMP] * ((double) item[ITEM_INTENSITY_AMP].vals[0] / (double) item[ITEM_VIOLENT_FORCE].vals[0])) +
-              ni[ITEM_VIOLENT_FORCE]);
-    }
+    int getBoostValue();
     int	selectRandomItem ();
     char	*selectRevengePhrase ();
     char	*selectGloatPhrase ();
@@ -185,6 +178,12 @@ class PLAYER
     int     Select_Random_Weapon();
     int     Select_Random_Item();
     int    Reduce_Time_Clock();
+
+    #ifdef NETWORK
+    void Trim_Newline(char *line);   // sanitize input
+    int Get_Network_Command();
+    int Execute_Network_Command(int my_turn);
+    #endif
   };
 
 #endif
