@@ -133,15 +133,15 @@ TANK::TANK (GLOBALDATA *global, ENVIRONMENT *env):PHYSICAL_OBJECT(),_target(NULL
   healthText = new FLOATTEXT (global, env, NULL, 0, 0, WHITE, CENTRE);
   if (!healthText)
     {
-      perror ( (char *)"tank.cc: Failed allocating memory for healthText in TANK::TANK");
-      exit (1);
+      perror ( "tank.cc: Failed allocating memory for healthText in TANK::TANK");
+      // exit (1);
     }
 
   shieldText = new FLOATTEXT (global, env, NULL, 0, 0, makecol (200, 200, 255), CENTRE);
   if (!shieldText)
     {
-      perror ( (char *)"tank.cc: Failed allocating memory for shieldText in TANK::TANK");
-      exit (1);
+      perror ( "tank.cc: Failed allocating memory for shieldText in TANK::TANK");
+      // exit (1);
     }
 
   if (global->name_above_tank)
@@ -149,8 +149,8 @@ TANK::TANK (GLOBALDATA *global, ENVIRONMENT *env):PHYSICAL_OBJECT(),_target(NULL
       nameText = new FLOATTEXT (global, env, NULL, 0, 0, WHITE, CENTRE);
       if (! nameText)
         {
-          perror ( (char *)"tank.cc: Failed allocating memory for nameText in TANK::TANK");
-          exit(1);
+          perror ( "tank.cc: Failed allocating memory for nameText in TANK::TANK");
+          // exit(1);
         }
     }
 
@@ -219,7 +219,7 @@ void TANK::newRound ()
   sprintf (buf, "%d", l);
   healthText->set_text (buf);
   // delay_fall = GRAVITY_DELAY;
-  delay_fall = abs(_env->landSlideDelay * 100);
+  delay_fall = (int) labs(_env->landSlideDelay * 100);
   fire_another_shot = 0;
   shots_fired = 0;
 
@@ -259,6 +259,23 @@ void TANK::applyDamage ()
           if ( killed )
             creditTo->kills++;
           creditTo->money += (int)(damage * _global->scoreHitUnit);
+          if (creditTo->tank)
+          {
+                char the_money[64];
+                sprintf(the_money, "$%s", Add_Comma( (int) (damage * _global->scoreHitUnit) ) );
+                // show how much the shooter gets
+                FLOATTEXT *moneyText = new FLOATTEXT(_global, _env, the_money,
+                                    (int) creditTo->tank->x, (int) creditTo->tank->y - 30,
+                                    makecol(0, 255, 0), CENTRE);
+                if (moneyText)
+                {
+                      // moneyText->xv = 0;
+                      // moneyText->yv = -0.5;
+                      moneyText->set_speed(0.0, -0.5);
+                      moneyText->maxAge = 200;
+                }
+                
+          }
           // this tank is destroyed, the attacker gloats
           if ( (killed) && (! creditTo->gloating) )
             {
@@ -271,15 +288,15 @@ void TANK::applyDamage ()
                                              temp_text,
                                              (int) creditTo->tank->x, (int) creditTo->tank->y - 30,
                                              creditTo->color, CENTRE);
-                  if (temp_text) free(temp_text);
-                  if (! gloatText)
-                    {
-                      perror ( (char *)"tank.cc: Failed allocating memory for gloatText in applyDamage.");
-                      exit(1);
-                    }
-                  gloatText->xv = 0;
-                  gloatText->yv = -0.4;
-                  gloatText->maxAge = 300;
+                  if (gloatText)
+                  {
+                    // gloatText->xv = 0;
+                    // gloatText->yv = -0.4;
+                    gloatText->set_speed(0.0, -0.4);
+                    gloatText->maxAge = 300;
+                  }
+                  else
+                      perror ( "tank.cc: Failed allocating memory for gloatText in applyDamage.");
                   creditTo->gloating = true;
                 }
             }
@@ -304,15 +321,15 @@ void TANK::applyDamage ()
                                                temp_text,
                                                (int)x, (int)y - 30,
                                                player->color, CENTRE);
-                  if (temp_text) free(temp_text);
-                  if (!revengeText)
-                    {
-                      perror ( (char *)"tank.cc: Failed allocating memory for revengeText in applyDamage");
-                      exit (1);
-                    }
-                  revengeText->xv = 0;
-                  revengeText->yv = -0.4;
-                  revengeText->maxAge = 300;
+                  if (revengeText)
+                  {
+                    // revengeText->xv = 0;
+                    // revengeText->yv = -0.4;
+                    revengeText->set_speed(0.0, -0.4);
+                    revengeText->maxAge = 300;
+                  }
+                  else
+                      perror ( "tank.cc: Failed allocating memory for revengeText in applyDamage");
                 }
             }
         }
@@ -330,15 +347,15 @@ void TANK::applyDamage ()
                                            player->selectSuicidePhrase(),
                                            (int) x, (int) y - 30,
                                            player->color, CENTRE);
-              if (temp_text) free(temp_text);
-              if (! suicideText)
-                {
-                  perror ( (char *)"tank.cc: Failed allocating memory for suicideText in applyDamage.");
-                  exit(1);
-                }
-              suicideText->xv = 0;
-              suicideText->yv = -0.4;
-              suicideText->maxAge = 300;
+              if (suicideText)
+              {
+                 // suicideText->xv = 0;
+                 // suicideText->yv = -0.4;
+                 suicideText->set_speed(0.0, -0.4);
+                 suicideText->maxAge = 300;
+              }
+              else
+                  perror ( "tank.cc: Failed allocating memory for suicideText in applyDamage.");
             }
         }
     }
@@ -362,15 +379,17 @@ void TANK::applyDamage ()
       damageText = new FLOATTEXT (_global, _env,
                                   NULL, (int)x, (int)y,
                                   makecol (255, 0, 0), CENTRE);
-      if (!damageText)
-        {
-          perror ( (char *)"tank.cc: Failed allocating memory for damageText in TANK::TANK");
-          exit (1);
-        }
-      damageText->set_text(buf);
-      damageText->xv = 0;
-      damageText->yv = -0.2;
-      damageText->maxAge = 300;
+      if (damageText)
+      {
+         damageText->set_text(buf);
+         // damageText->xv = 0;
+         // damageText->yv = -0.2;
+         damageText->set_speed(0.0, -0.2);
+         damageText->maxAge = 300;
+         // damageText->sway = NORMAL_SWAY;
+      }
+      else
+          perror ( "tank.cc: Failed allocating memory for damageText in TANK::TANK");
     }
   if (sh > 0)
     {
@@ -379,7 +398,7 @@ void TANK::applyDamage ()
     }
   else
     {
-      shieldText->set_text ( (char *)"");
+      shieldText->set_text ( "");
     }
   sprintf (buf, "%d", l);
   healthText->set_text (buf);
@@ -399,6 +418,21 @@ int TANK::applyPhysics (GLOBALDATA *global)
   int stable = 0;
   int landed_on_tank;
 
+  // if we are buried, rockets shouldn't work
+  if ( howBuried() )
+  {
+    xv = 0;
+    if (yv < 0)
+       yv = 0;
+  }
+
+  // make sure the tank does not leave the screen when flying
+  if ( (yv < 0) && (y < TANKHEIGHT) )
+     yv = 0;
+
+  if (yv < 0)
+      x += xv * 4;
+
   if (!flashdamage)
     {
       if (x + xv < 1 || x + xv > (_global->screenWidth-1))
@@ -501,31 +535,31 @@ void TANK::explode ()
       player->revenge = creditTo;
       temp_text = player->selectRevengePhrase();
       revengeText = new FLOATTEXT (_global, _env,
-                                   // player->selectRevengePhrase ((double)damage / maxLife),
                                    temp_text,
                                    (int)x, (int)y - 30,
                                    player->color, CENTRE);
-      if (temp_text) free(temp_text);
-      if (!revengeText)
-        {
-          perror ( (char *)"tank.cc: Failed allocating memory for revengeText in TANK::explode");
-          exit (1);
-        }
-      revengeText->xv = 0;
-      revengeText->yv = -0.4;
-      revengeText->maxAge = 300;
+      if (revengeText)
+      {
+          // revengeText->xv = 0;
+          // revengeText->yv = -0.4;
+          revengeText->set_speed(0.0, -0.4);
+          revengeText->maxAge = 300;
+      }
+      else
+          perror ( "tank.cc: Failed allocating memory for revengeText in TANK::explode");
     }
   explosion = new EXPLOSION (_global, _env, x, y, 1);
-  if (!explosion)
-    {
-      perror ( (char *)"tank.cc: Failed allocating memory for explosion in TANK::explode");
-      exit (1);
-    }
-  explosion->player = player;
-  explosion->bIsWeaponExplosion = false;
-  destroy = TRUE;
+  if (explosion)
+  {
+     explosion->player = player;
+     explosion->bIsWeaponExplosion = false;
+  }
+  else
+      perror ( "tank.cc: Failed allocating memory for explosion in TANK::explode");
+  
 
-  play_sample ((SAMPLE *)_global->SOUND[WEAPONSOUNDS].dat, 255, 128, 1000, 0);
+  destroy = TRUE;
+  play_sample ((SAMPLE *)_global->sounds[WEAPONSOUNDS], 255, 128, 1000, 0);
 }
 
 void TANK::repulse (double xpos, double ypos, double *xaccel, double *yaccel, int aWeaponType)
@@ -593,6 +627,18 @@ void TANK::draw (BITMAP *dest, int healthOffset)
           turret_x = x;
           turret_y = y + (TANKHEIGHT / 2);
           break;
+        case BIGGREY_TANK:
+          use_tank_bitmap = 9;
+          use_turret_bitmap = 2;
+          turret_y = y;
+          turret_x = x;
+          break;
+        case T34_TANK:
+          use_tank_bitmap = 10;
+          use_turret_bitmap = 3;
+          turret_y = y;
+          turret_x = x;
+          break;
         default:
           use_tank_bitmap = 0;
           use_turret_bitmap = 0;
@@ -613,6 +659,7 @@ void TANK::draw (BITMAP *dest, int healthOffset)
       int phaseValue = 1;
 
       drawing_mode(DRAW_MODE_TRANS, NULL, 0, 0);
+      _env->current_drawing_mode = DRAW_MODE_TRANS;
       set_trans_blender (0, 0, 0, (int)50);
       // avoid sub-index
       if ( shPhase < 0 )
@@ -635,25 +682,31 @@ void TANK::draw (BITMAP *dest, int healthOffset)
                    TANKWIDTH + 6 + phaseValue, TANKHEIGHT - 1, shieldColor);
         }
       drawing_mode(DRAW_MODE_SOLID, NULL, 0, 0);
+      _env->current_drawing_mode = DRAW_MODE_SOLID;
     }
-  draw_sprite (dest, (BITMAP *) _global->gfxData.T[use_tank_bitmap].dat, (int) x - TANKWIDTH, (int) y);
+  draw_sprite (dest, (BITMAP *) _global->tank[use_tank_bitmap], (int) x - TANKWIDTH, (int) y);
   turretAngle = (int) ((float) (90 - a) * ((float) 256 / (float) 360));
-  rotate_sprite (dest, (BITMAP *) _global->gfxData.TG[use_turret_bitmap].dat,
+  rotate_sprite (dest, (BITMAP *) _global->tankgun[use_turret_bitmap],
                  (int) turret_x - GUNLENGTH, (int) turret_y - (GUNLENGTH - 2), itofix (turretAngle));
 
+
+  // when using rockets, show flame
+  if (yv < 0)
+  {
+      rectfill(dest, (int) x - TANKWIDTH, (int) y + TANKHEIGHT, x + TANKWIDTH, y + TANKHEIGHT + 10, makecol(250, 150, 0) );
+  }
+
   if (sh > 0)
     setUpdateArea ((int)x - TANKWIDTH - 15, (int)y - TANKHEIGHT,
-                   ((TANKWIDTH + 15) * 2) + 1, (TANKHEIGHT * 2) + 1);
+                   ((TANKWIDTH + 15) * 2) + 1, (TANKHEIGHT * 2) + 20);
   else
     setUpdateArea ((int)x - GUNLENGTH - 1, (int)y - GUNLENGTH - 1,
-                   (GUNLENGTH * 2) + 2, TANKHEIGHT + GUNLENGTH + 1);
-
+                   (GUNLENGTH * 2) + 2, TANKHEIGHT + GUNLENGTH + 20);
   if (para)
     {
-      draw_sprite (dest, (BITMAP *) _global->gfxData.T[para].dat,
+      draw_sprite (dest, (BITMAP *) _global->tank[para],
                    (int) (x - TANKWIDTH) - 3, (int) y - 25);
-      addUpdateArea ((int)(x - TANKWIDTH) - 3, (int)y - 25,
-                     35, 46);
+      addUpdateArea ((int)(x - TANKWIDTH) - 3, (int)y - 25, 35, 66);
     }
 
   printHealth (healthOffset);
@@ -734,7 +787,8 @@ void TANK::activateCurrentSelection ()
     return;
 
   // remove status from top bar at next redraw
-  _global->tank_status[0] = 0;
+  if (_global->tank_status)
+      _global->tank_status[0] = 0;
 
   _env->time_to_fall--;
   if (_env->time_to_fall < 0)
@@ -753,7 +807,7 @@ void TANK::activateCurrentSelection ()
 
       if (cw < BALLISTICS)
         {
-          play_sample ((SAMPLE *) _global->SOUND[weapon[cw].sound].dat, 255, 128, 1000, 0);
+          play_sample ((SAMPLE *) _global->sounds[weapon[cw].sound], 255, 128, 1000, 0);
           for (z = 0; z < _env->am; z++)
             {
               MISSILE *newmis;
@@ -772,14 +826,14 @@ void TANK::activateCurrentSelection ()
                                    turret_x + (_global->slope[ca][0] * GUNLENGTH) /*- mxv*/,
                                    turret_y + (_global->slope[ca][1] * GUNLENGTH) /*- myv*/,
                                    mxv, myv, cw);
-              if (!newmis)
-                {
+              if (newmis)
+              {
+                newmis->physics = 0;
+                newmis->age = 0;
+                newmis->player = player;
+              }
+              else
                   perror ( (char *)"tank.cc: Failed allocating memory for newmis in TANK::activateCurrentSelection");
-                  exit (1);
-                }
-              newmis->physics = 0;
-              newmis->age = 0;
-              newmis->player = player;
               // set up volley
               if (! fire_another_shot)
                 {
@@ -804,7 +858,7 @@ void TANK::activateCurrentSelection ()
         }
       else          // BEAM weapon
         {
-          play_sample ((SAMPLE *) _global->SOUND[weapon[cw].sound].dat, 255, 128, 1000, 0);
+          play_sample ((SAMPLE *) _global->sounds[weapon[cw].sound], 255, 128, 1000, 0);
           for (z = 0; z < _env->am; z++)
             {
               BEAM *newbeam;
@@ -816,14 +870,14 @@ void TANK::activateCurrentSelection ()
                                   turret_x + (_global->slope[ca][0] * GUNLENGTH),
                                   turret_y + (_global->slope[ca][1] * GUNLENGTH),
                                   ca, cw);
-              if (!newbeam)
-                {
-                  perror ( (char *)"tank.cc: Failed allocating memory for newbeam in TANK::activateCurrentSelection");
-                  exit (1);
-                }
-              newbeam->physics = 0;
-              newbeam->age = 0;
-              newbeam->player = player;
+              if (newbeam)
+              {
+                 newbeam->physics = 0;
+                 newbeam->age = 0;
+                 newbeam->player = player;
+              }
+              else
+                  perror ( "tank.cc: Failed allocating memory for newbeam in TANK::activateCurrentSelection");
             }
 
         }
@@ -843,8 +897,8 @@ void TANK::activateCurrentSelection ()
           teleport = new TELEPORT (_global, _env, this, teleXDest, teleYDest, TANKHEIGHT * 4 + GUNLENGTH, 120);
           if (!teleport)
             {
-              perror ( (char *)"tank.cc: Failed allocating memory for teleport in TANK::activateCurrentSelection");
-              exit (1);
+              perror ( "tank.cc: Failed allocating memory for teleport in TANK::activateCurrentSelection");
+              // exit (1);
             }
         }
       else if (itemNum == ITEM_SWAPPER)
@@ -870,10 +924,47 @@ void TANK::activateCurrentSelection ()
           other_teleport = new TELEPORT (_global, _env, other_tank, (int) x, (int) y, TANKHEIGHT * 4 + GUNLENGTH, 120);
 
         }
+      else if (itemNum == ITEM_MASS_TELEPORT)
+      {
+          TELEPORT *my_teleport;
+          int count;
+          int XDest, YDest;
+          TANK *current_tank;
+          
+          for (count = 0; count < _global->numPlayers; count++)
+          {
+             current_tank = _global->players[count]->tank;
+             if (current_tank)
+             {
+                XDest = (rand () % (_global->screenWidth - TANKWIDTH * 2)) + TANKWIDTH;
+                YDest = (rand () % (_global->screenHeight - TANKHEIGHT * 2)) + TANKHEIGHT;
+                creditTo = player;
+                my_teleport = new TELEPORT(_global, _env, current_tank, XDest, YDest, TANKHEIGHT * 4 + GUNLENGTH, 120);
+             }
+          }
+             
+      }
+
+      else if ( itemNum == ITEM_ROCKET )
+      {
+         yv = -10;
+         y -= 10;
+         if (a < 180)
+         {
+               xv += 0.3;
+         }
+         else if (a > 180)
+         {
+              xv -= 0.3;
+         }
+
+         applyPhysics(_global);
+      }
+
       else if ( itemNum == ITEM_FAN )
         {
           // play wind sound
-          play_sample ((SAMPLE *) _global->SOUND[2].dat, 255, 128, 1000, 0);
+          play_sample ((SAMPLE *) _global->sounds[2], 255, 128, 1000, 0);
           if (a < 180)   // move wind to the right
             _env->wind += (p / 20);
           else     // wind to the left
@@ -900,6 +991,7 @@ void TANK::activateCurrentSelection ()
   // then switch to another
   if (! player->nm[cw] )
     {
+      cw = WEAPONS - 1;
       while ( (cw > 0) && (! player->nm[cw] ) )
         cw--;
       player->changed_weapon = true;
@@ -1121,3 +1213,5 @@ void TANK::setEnvironment(ENVIRONMENT *env)
       _index = _env->addObject (this);
     }
 }
+
+
