@@ -36,12 +36,6 @@ class EXPLOSION;
 class FLOATTEXT;
 class TANK: public PHYSICAL_OBJECT
   {
-  private:
-    // empty ctor, copy-ctor and assign operator are private, so the compiler won't create implicit ones!
-    inline TANK () { }
-    inline TANK (TANK &sourceTank _UNUSED)_UNUSED;
-    inline const TANK& operator= (const TANK &sourceTank) { return(sourceTank); }
-
   protected:
     int	_targetX,_targetY;
     int	_prevTargetX,_prevTargetY;
